package com.muyu.rule.server.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.rule.common.domain.RuleEngineVersion;
import com.muyu.rule.common.domain.req.VersionAddReq;
import com.muyu.rule.common.utils.OssUtil;
import com.muyu.rule.server.service.RuleEngineVersionService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @Author：张承志
 * @Package：com.muyu.rule.server.controller
 * @Project：cloud-etl-rule
 * @name：RuleEngineVersionController
 * @Date：2024/8/25 10:41
 */
@Log4j2
@RestController
@RequestMapping("/version")
@RequiredArgsConstructor
@Tag(name = "规则版本控制层", description = "规则版本管理,查看等相关操作")
public class RuleEngineVersionController {

    @Autowired
    private RuleEngineVersionService versionService;

    /**
     * 添加规则引擎版本
     * @param versionAddReq 引擎版本添加实体类
     * @return
     */


 @PostMapping("/insertVersion")
 @Operation(summary = "规则引擎版本",description = "通过传入版本添加的实体类,进行规则引擎的版本添加")
    public Result insertVersion(@Validated @RequestBody VersionAddReq versionAddReq){

     versionService.save(RuleEngineVersion.addBuild(versionAddReq));

     return  Result.success();
 }

    /**
     * 激活引擎请求
     * @param id
     * @return
     */
    @PostMapping("/activate/{id}")
    @Operation(summary = "规则引擎的激活", description = "通过Id激活规则引擎")
    public Result activate(@PathVariable("id") Long id){

        versionService.activate(id);

        return Result.success();
    }

    /**
     * 取消引擎请求
     */


    @PostMapping("/disable/{id}")
    @Operation(summary = "规则引擎的取消", description = "通过Id取消规则引擎")
    public Result disable(@PathVariable("id") Long id){

        versionService.disable(id);

        return Result.success();
    }


    /**
     * 上传
     * @param versionClazz
     * @return
     */


    @PostMapping("/deposit/{versionClazz}/{className}")
    public Result deposit(@PathVariable("versionClazz") String versionClazz, @PathVariable("className") String  className){

        versionService.Upload(versionClazz,className);

        return Result.success();
    }













}
